@@ -1,4 +1,4 @@
-GOOF----LE-8-2.0aU      ]  4  h      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  price-quotes	 		g  filenameS	
+GOOF----LE-8-2.0S      ]  4    h      ] g  guile	 	g  define-module*	 	 	g  gnucash	g  price-quotes	 		g  filenameS	
 f  price-quotes.scm	g  set-current-module	 	
  	g  call-with-deferred-observers	 	 	g  module-export!	 	 	g  current-module	 	 	g  gnc:book-add-quotes	 	g   gnc:price-quotes-install-sources	 	g  process-use-modules	 	 	g  main	 	  	!g  
 gnc-module	"! 	#" 	$g  
@@ -11,9 +11,9 @@ filter-map	ag  gnc-commodity-get-namespace	bf  :	cg  gnucash-ui-is-running
 Run 'gnc-fq-update' as root to install them.	lf  
 	mg  system-error	nf  ;There was a system error while retrieving the price quotes.	og  call-with-output-string	pf  *Unable to retrieve quotes for these items:	qf    	rg  string-join	sf  
   	tg  gnc-verify-dialog	uf  $Continue using only the good quotes?	vf  Continuing with good quotes.	wf  =There was an unknown error while retrieving the price quotes.	xg  first	yg  second	zg  third	{g  assq-ref	|g  gnc:time-no-zone	}g  currency	~g  string?	g  gnc-commodity-table-lookup f  ISO4217 g  
-string-upcase g  gnc-pricedb-get-db g  gnc-commodity-get-printname g  symbol g  or-map g  last g  nav g  price   f  last f  nav f  unknown g  double-to-gnc-numeric g  GNC-DENOM-AUTO g  GNC-DENOM-SIGFIGS g  
+string-upcase g  gnc-pricedb-get-db g  gnc-commodity-get-printname g  or-map g  last g  nav g  price   f  last f  nav f  unknown g  double-to-gnc-numeric g  GNC-DENOM-AUTO g  GNC-DENOM-SIGFIGS g  
 GNC-RND-ROUND g  gnc-parse-time-to-time64 f  %Y-%m-%d %H:%M:%S g  
-gnc:get-today g  gnc-pricedb-lookup-day g  gnc-numeric-invert g  gnc-price-create g  gnc-price-begin-edit g  gnc-price-set-commodity g  gnc-price-set-currency g  gnc-price-set-time g  gnc-price-set-source g  PRICE-SOURCE-FQ g  gnc-price-set-typestr g  gnc-price-set-value g  gnc-price-commit-edit g  gnc-price-get-source g  any f  (Unable to create prices for these items: f  Add remaining good quotes? f  Adding remaining good quotes. g  gnc-pricedb-add-price g  gnc-price-unref g  format f  Found Finance::Quote version ~A g  gnc:msg f  Found Finance::Quote version  g  !gnc-quote-source-set-fq-installedC 5    hD  7  ]4	
+gnc:get-today g  gnc-pricedb-lookup-day g  gnc-price-create g  gnc-price-begin-edit g  gnc-price-set-commodity g  gnc-price-set-currency g  gnc-price-set-time g  gnc-price-set-source g  PRICE-SOURCE-FQ g  gnc-price-set-typestr g  gnc-price-set-value g  gnc-price-commit-edit g  gnc-price-get-source g  any f  (Unable to create prices for these items: f  Add remaining good quotes? f  Adding remaining good quotes. g  gnc-pricedb-add-price g  gnc-price-unref g  format f  Found Finance::Quote version ~A g  gnc:msg f  Found Finance::Quote version  g  !gnc-quote-source-set-fq-installedC 5      hB  7  ]4	
 5 4
  >  "  G   4       h   B   ] 45 6   :       g  filenamef  price-quotes.scm
 	
@@ -156,68 +156,52 @@ alist-item
 		!  g  filenamef  price-quotes.scm
 			!					"		?		"		"		"		>		"	!	! 		!   CcdefghijklmnoEepHqrs        hP      ]445 >  "  G  4 >  "  G  4 >  "  G  4L 5 6       g  p
 		P  g  filenamef  price-quotes.scm
-&		'		(		
-(		(		'		)		.*		2*		9*		D+		J+	7	L+		P+	 		P   CtEepHqrsu 	h      ]445 >  "  G  4 >  "  G  4 >  "  G  44L 5 >  "  G  4 >  "  G  45 6            g  p
+						
+								.		2		9		D		J	7	L		P	 		P   CtEepHqrsu 	h      ]445 >  "  G  4 >  "  G  4 >  "  G  44L 5 >  "  G  4 >  "  G  45 6            g  p
 		{  g  filenamef  price-quotes.scm
-						
-								.		2		9		B 		E 		K 	6	M 		T 		]!		q"		u"		w"		{"	 		{   CEepHqrsv 	    h     ]445 >  "  G  4 >  "  G  4 >  "  G  44L 5 >  "  G  4 >  "  G  445 >  "  G   6         g  p
+						
+								.		2		9		B		E		K	6	M		T		]		q		u		w		{	 		{   CEepHqrsv 	    h     ]445 >  "  G  4 >  "  G  4 >  "  G  44L 5 >  "  G  4 >  "  G  445 >  "  G   6         g  p
 	   g  filenamef  price-quotes.scm
-/		0		0		
-0		0		0		1		.2		22		92		B3		E3		K3	1	M3		T3		]4		o5		r5		v5		x5		5	 6	 	    Cwxyz{|}K~{     h       ]	4L  5$  
+!		"		"		
+"		"		"		#		.$		2$		9$		B%		E%		K%	1	M%		T%		]&		o'		r'		v'		x'		'	 (	 	    Cwxyz{|}K~{       h       ]	4L  5$  
 N NCC        g  	price-sym
 		 g  p		  g  filenamef  price-quotes.scm
-											 		   C0bY / hH    ]i4 5H4 >  "  G  4 545HHH454L 5$  $45$  4	
+z		{		{		|		}		~	 		   C0bY -   h    ]Y4 54 >  "  G  4 545HHH454L 5$  $45$  4	
 455"  "  4L 5	H
 4
-J54
-5$  F45$  $45$  4	
-455"  "  
-
-K
-"   4O >  "  G  J$  "  $  "  $  "  KJ$  4J4		55K"   J$  J45
-K"  45 K"   4!J56J$ $ J$ J$ J$ 4"	JJ5K
+>  "  G  4O >  "  G  J$  "  $  "  $  "  KJ$  4J4		55K"   J$  J45
+K"  45 K"  4 56$ $ vJ$ lJ$ bJ$ X4!	J5K
 J
-(  &4"	JJ5K
-J
-(  "  	4#J5K"   J
-(  4$L 5$  4%>  "  G  4&J>  "  G  4'>  "  G  4(J>  "  G  4)*>  "  G  4+J>  "  G  4,J>  "  G  4->  "  G  C 4!J564.J
-5*$  v4%J
->  "  G  4(J
-J>  "  G  4)J
-*>  "  G  4+J
-J>  "  G  4,J
-J>  "  G  4-J
->  "  G  CC"K"G"C"?";            g  triple
-	B g  	commodity		B g  
-quote-data		$B g  gnc-time		/B g  price		2B g  
-price-type		5B g  currency-str		@B g  commodity-table		IB g  currency		vB g  pricedb			B g  saved-price	
- B g  
-commodity-str	 B g  symbol	   g  
-other-curr	
-   g  key	 3 g  timestr	\l g  	gnc-price	  g  filenamef  price-quotes.scm
-:		g			g		h		i		$g		'j		-j	*	/j		/g		8m		>m	.	@m		@g		Cn		Ig		Qp		Rq		\p		]r		cs	-	dt	-	lr		vg		yu		g	 w	 g	 y	 y	
- y	 z	 z	. z	 z	
- |	 }	 |	 ~	 ~	C 	3 ~	 z	
- 	 	 	 	 	
-			)	+	5	;	<	C	3L	+N	P	
-Z	\	_a	
-ea	,ga	
-ia	n	
-s	y	
-			
-						$			"						
-	!	5	I	]	q			"	&										 k	B   C~EeHqrM~s   h     ]445 >  "  G  4 >  "  G  4 >  "  G  444L 5	5 >  "  G  4 >  "  G  4
+(  4"L 5$  4#>  "  G  4$>  "  G  4%>  "  G  4&J>  "  G  4'(>  "  G  4)J>  "  G  4*J>  "  G  4+>  "  G  C4 564,J
+5($  v4#J
+>  "  G  4&J
+J>  "  G  4'J
+(>  "  G  4)J
+J>  "  G  4*J
+J>  "  G  4+J
+>  "  G  CC"w"s"o"k"g           g  triple
+	 g  	commodity		 g  
+quote-data		$ g  gnc-time		/ g  price		2 g  
+price-type		5 g  currency-str		@ g  commodity-table		I g  currency		v g  pricedb			 g  saved-price	
+  g  key	   g  timestr	! g  	gnc-price	{1  g  filenamef  price-quotes.scm
+,		g			g		h		i		$g		'j		-j	*	/j		/g		8m		>m	.	@m		@g		Cn		Ig		Qp		Rq		\p		]r		cs	-	dt	-	lr		vg		yu		g	 w	 z	 	 z	 	 	 	 	 	 	 	 	 	 	3	+		
+		a	
+a	,a	
+a	#	
+(	.	
+8	9	A	
+A	M	`	n	t	u	{										(	")	&1	2	;	?	@	R	f	z			 T	   C~EeHqrM~s      h     ]445 >  "  G  4 >  "  G  4 >  "  G  444L 5	5 >  "  G  4 >  "  G  4
 5 6            g  p
 	   g  filenamef  price-quotes.scm
-C		D		D		
-D	 	D		D		E		.F		2F		9F		BG		EG		HG	*	RG	B	TG		[G		dH		xI		|I	 	~I	 I	 	    CEeHqrM~s     h     ]445 >  "  G  4 >  "  G  4 >  "  G  444L 5	5 >  "  G  4 >  "  G  44
+5		6		6		
+6	 	6		6		7		.8		28		98		B9		E9		H9	*	R9	B	T9		[9		d:		x;		|;	 	~;	 ;	 	    CEeHqrM~s     h     ]445 >  "  G  4 >  "  G  4 >  "  G  444L 5	5 >  "  G  4 >  "  G  44
 5 >  "  G   6          g  p
 	   g  filenamef  price-quotes.scm
-L		M		M		
-M		M		M		N		.O		2O		9O		BP		EP		HP	)	RP	A	TP		[P		dQ		vR		yR		}R		R	 R	 S	 	    C~    h   f   ]4 5C     ^       g  x
+>		?		?		
+?		?		?		@		.A		2A		9A		BB		EB		HB	)	RB	A	TB		[B		dC		vD		yD		}D		D	 D	 E	 	    C~    h   f   ]4 5C     ^       g  x
 		  g  filenamef  price-quotes.scm
-W	#	W	4	
-W	/ 		   C        h8   s   ] $  (4L  >  "  G  4 >  "  G  CC      k       g  price
+I	#	I	4	
+I	/ 		   C        h8   s   ] $  (4L  >  "  G  4 >  "  G  CC      k       g  price
 		2  g  filenamef  price-quotes.scm
 									 		2   C 5 h  	  ]R4545H44>  G K54	5"  94J	
 >  "  G  4
@@ -256,40 +240,34 @@ fq-results	  g  result-list	 [ g  process-a-quote	 X g  
 -	1	5	9	<	=	
 E	F	
 K	O	Q	V	
-c 	
-f 	j 	l 	n	/s 	
-						
-		
-				
-	
-				V	
-					)				
-		
-			
-'	,$	1%	A$	L,	P	
-\	e	k	x	z	-	
-.	-	
-								
-	
-
-		
-				
-
-	
-
-	
-	
-	
-	X
-	
-8	
-:	:	=	)=	*>	2>	3A	9B	FA	H?	MJ	PK	`J	rU	sV	"{V	~			 		  g  nameg  gnc:book-add-quotes CR?H      hX   
+c	
+f	j	l	n	/s	
+						
+		
+				
+	
+				V	
+			 	 	)				
+		
+			
+'	,	1	A	L	P		
+\		e	k
+	x	z
+		
+ 		
+								
+		
+				
+	
+				X	
+*	
+,	,	/	)/	*0	20	33	94	F3	H1	M<	P=	`<	rG	sH	"{H	~			 		  g  nameg  gnc:book-add-quotes CR?H      hX   
   ]45   $  B4 >  "  G  4>   "  G  4 >  "  G   6C          g  sources
 		T  g  filenamef  price-quotes.scm
-h
-	i		i		j		j		l		l		l	3	l		'm		7n	
-	;n		>n	3	Cn	
-	Po	-	Ro	
+Z
+	[		[		\		\		^		^		^	3	^		'_		7`	
+	;`		>`	3	C`	
+	Pa	-	Ra	
  		T
   g  nameg   gnc:price-quotes-install-sources CRC      /      g  m
 	
@@ -315,7 +293,7 @@ fq-results	  g  result-list	 [ g  process-a-quote	 X g  
 	q	
 	p
 	s
-C 
-Dh
- 	D
+A` 
+BZ
+ 	B
    C6 
\ No newline at end of file
